@@ -99,18 +99,19 @@ pcacrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
    dim(sqmodulus) <- c(sigsize * nscale, 1)
 
    z <- .C("Spointmap",
-	as.double(sqmodulus),
-        as.integer(sigsize),
-	as.integer(nscale),
-	as.integer(gridb),
-	as.integer(grida),
-	as.integer(nbblock),
-	as.integer(nbpoint),
-        pointmap = as.integer(pointmap),
-	tst =as.single(tst),
-	as.integer(tstsize),
-	as.integer(count),
-	as.integer(seed))
+           as.double(sqmodulus),
+           as.integer(sigsize),
+           as.integer(nscale),
+           as.integer(gridb),
+           as.integer(grida),
+           as.integer(nbblock),
+           as.integer(nbpoint),
+           pointmap = as.integer(pointmap),
+           tst =as.single(tst),
+           as.integer(tstsize),
+           as.integer(count),
+           as.integer(seed),
+           PACKAGE="Rwave")
   
    pointmap <- z$pointmap
    tst <- z$tst
@@ -275,19 +276,20 @@ pcacrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
    dim(pcamap) <- c(nscale * sigsize, 1)
      
    z <- .C("Spca_annealing",
-        as.double(sqmodulus),
-        beemap= as.double(beemap),
-	as.integer(pcamap),
-        as.single(rate),
-	as.integer(sigsize),
-        as.integer(nscale),
-        as.integer(iteration),
-	as.integer(seed),
-        as.integer(bstep),
-        as.integer(nbclimb),
-	as.integer(flag.int),
-	as.integer(chain),
-	as.integer(flag.temp))
+           as.double(sqmodulus),
+           beemap= as.double(beemap),
+           as.integer(pcamap),
+           as.single(rate),
+           as.integer(sigsize),
+           as.integer(nscale),
+           as.integer(iteration),
+           as.integer(seed),
+           as.integer(bstep),
+           as.integer(nbclimb),
+           as.integer(flag.int),
+           as.integer(chain),
+           as.integer(flag.temp),
+           PACKAGE="Rwave")
 
    beemap <- z$beemap
    dim(beemap) <- c(sigsize, nscale)
@@ -343,16 +345,17 @@ pcafamily <-function(pcaridge, orientmap,
 	
    
    z <- .C("Spca_family",
-        as.double(pcaridge),
-        as.integer(orientmap),
-        orderedmap = as.single(orderedmap),
-	chain = as.integer(chain),
-	chainnb = as.integer(nbchain),
-	as.integer(sigsize),
-        as.integer(nscale),
-        as.integer(bstep),
-	as.single(threshold),
-	as.integer(maxchnlng))
+           as.double(pcaridge),
+           as.integer(orientmap),
+           orderedmap = as.single(orderedmap),
+           chain = as.integer(chain),
+           chainnb = as.integer(nbchain),
+           as.integer(sigsize),
+           as.integer(nscale),
+           as.integer(bstep),
+           as.single(threshold),
+           as.integer(maxchnlng),
+           PACKAGE="Rwave")
 	
    orderedmap <- z$orderedmap
    chain <- z$chain
@@ -379,11 +382,12 @@ pcamaxima <- function(beemap,orientmap)
    dim(tfmaxima) <- c(nscale * sigsize, 1)   
 
    z <- .C("Stf_pcaridge",
-        as.double(beemap),
-        tfmaxima = as.double(tfmaxima),
-	as.integer(sigsize),
-        as.integer(nscale),
-        as.integer(orientmap))
+           as.double(beemap),
+           tfmaxima = as.double(tfmaxima),
+           as.integer(sigsize),
+           as.integer(nscale),
+           as.integer(orientmap),
+           PACKAGE="Rwave")
 	
    tfmaxima <- z$tfmaxima
    dim(tfmaxima) <- c(sigsize,nscale)   
@@ -425,7 +429,7 @@ simplepcarec <- function(siginput, tfinput, beemap, orientmap, bstep = 5,
    nbchain <- tmp$nbchain
    rec <- numeric(length(siginput))
 
-   if(plot != FALSE){
+   if(plot != FALSE) {
      par(mfrow=c(2,1))
      plot.ts(siginput)
      title("Original signal")
@@ -450,7 +454,7 @@ simplepcarec <- function(siginput, tfinput, beemap, orientmap, bstep = 5,
       rec <- rec + Re(tmp3[j,])
    }
 
-   if(plot == 1){
+   if(plot == 1) {
       par(mfrow=c(2,1))
       par(cex=1.1)
       plot.ts(siginput)
@@ -458,7 +462,7 @@ simplepcarec <- function(siginput, tfinput, beemap, orientmap, bstep = 5,
       plot.ts(rec)
       title("Reconstructed signal")
    }
-   else if (plot == 2){
+   else if (plot == 2) {
       par(mfrow=c(nbchain+2,1))
       par(mar=c(2,4,4,4))
       par(cex=1.1)
@@ -471,6 +475,6 @@ simplepcarec <- function(siginput, tfinput, beemap, orientmap, bstep = 5,
         
       plot.ts(rec)
       title("Reconstructed signal")
-   }
-   list(rec=rec, ordered=tmp$ordered,chain = tmp$chain, comp=tmp3)
+    }
+   list(rec=rec, ordered=tmp$ordered, chain = tmp$chain, comp=tmp3)
 }
